@@ -1,4 +1,4 @@
-from tqdm import trange
+from tqdm import *
 from time import sleep
 from random import randint
 from os import system
@@ -14,18 +14,20 @@ help_cont[1] = 'fuckstar : One Button to fuck Satellite'
 help_cont[2] = 'lifeGame : Play the Life Game'
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
-help_cont[5] = 'func5'
+help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
 
 
 def help(page=1,lines = 5):
-    maxPage = len(help_cont)//lines
+    maxPage = int((0.5+len(help_cont))/lines)+1
     if (page - 1) * lines >= len(help_cont):
         aprint(f'Page Error, check the number : [{1},{maxPage}]')
         return
     print(f"{'=-'*14}= H E L P {'=-'*14}=\n")
     for i in range(lines):
-        n = i+lines*(page-1)
-        print(f"   {n} - {help_cont[n]}")
+        try:
+            n = i+lines*(page-1)
+            print(f"   {n} - {help_cont[n]}")
+        except:break
     print(f"\n{'=-'*14} page({page}/{maxPage}) {'-='*14}")
     if page < maxPage:print(f'\t\t\thelp({page+1}) for next page')
 
@@ -55,6 +57,9 @@ def paint():
     draw()
     
 def b64tofile():
+    '''
+    Encode/Decode a file by Base64
+    '''
     menu = '''
 please choose mode (1/2):
     - 1. encode
@@ -76,11 +81,44 @@ please choose mode (1/2):
     with open(f2,'wb') as ff:
         ff.write(df)
     
-def func5():
-    print('func5')
+def prove(cont):
+    '''
+    Only the format is supported
+    sha256(XXXX + {a}) = {b}
+    '''
+    from itertools import product
+    import re
+    from string import ascii_letters,digits
+    from hashlib import sha256
 
+    
+    cont = cont.replace(' ','')
+    #print(cont)
+    p = re.compile('sha256(.*?)=(.*)')
+    #print(p.findall(cont)[0])
+    r = p.findall(cont)[0]
+    L = len(r[0].split('+')[0])-1
+    a = r[0].split('+')[1][:-1]
+    b = r[1]
+    print(f"Proving:\n\tsha256({'X'*L} + {a}) = {b}\n")
+    s = list(product(ascii_letters+digits,repeat=L))
+    bar = tqdm(s)
+    ss = lambda d:sha256(d.encode()).hexdigest()
+    for i in bar:
+        S = ''.join(i)
+        bar.set_description(f"trying: {S}")
+        if ss(S+a) == b:
+            print('Find ,',S)
+            return S
+    
+        
+        
+    
+    
 def main():
-    b64tofile()
+    help()
+    #r = prove('sha256(XXX + O3) = a289ace0c0301fba709365606da60acf11d793869a7c76083cef6c1ac6ff1396')
+    #print(r)
 
 if __name__ == '__main__':
     main()
